summaryrefslogtreecommitdiff
path: root/src/theory/bags/bag_solver.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/theory/bags/bag_solver.h')
-rw-r--r--src/theory/bags/bag_solver.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/theory/bags/bag_solver.h b/src/theory/bags/bag_solver.h
index 9155c93d0..45a20e055 100644
--- a/src/theory/bags/bag_solver.h
+++ b/src/theory/bags/bag_solver.h
@@ -46,15 +46,15 @@ class BagSolver : protected EnvObj
/** apply inference rules for empty bags */
void checkEmpty(const Node& n);
/**
* apply inference rules for MK_BAG operator.
* Example: Suppose n = (bag x c), and we have two count terms (bag.count x n)
* and (bag.count y n).
* This function will add inferences for the count terms as documented in
- * InferenceGenerator::mkBag.
+ * InferenceGenerator::bagMake.
* Note that element y may not be in bag n. See the documentation of
* SolverState::getElements.
*/
- void checkMkBag(const Node& n);
+ void checkBagMake(const Node& n);
/**
* @param n is a bag that has the form (op A B)
* @return the set union of known elements in (op A B) , A, and B.
@@ -46,15 +46,15 @@ class BagSolver : protected EnvObj
void checkEmpty(const Node& n);
/**
- * apply inference rules for MK_BAG operator.
+ * apply inference rules for BAG_MAKE operator.
* Example: Suppose n = (bag x c), and we have two count terms (bag.count x n)
* and (bag.count y n).
generated by cgit on debian on lair
contact matthew@masot.net with questions or feedback